==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostka.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.Branch;
import pl.topteam.dps.enums.OrganProwadzacy;
import pl.topteam.dps.enums.TypJednostki;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DpsJednostka extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DPS_JEDNOSTKA.ADRES_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long adresId;

    /**
     * DPS_JEDNOSTKA.BRANCH
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Branch branch;

    /**
     * DPS_JEDNOSTKA.KOD_KESO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodKeso;

    /**
     * DPS_JEDNOSTKA.KOD_LOKALIZACJI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodLokalizacji;

    /**
     * DPS_JEDNOSTKA.KRS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String krs;

    /**
     * DPS_JEDNOSTKA.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * DPS_JEDNOSTKA.NAZWA_SKROCONA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwaSkrocona;

    /**
     * DPS_JEDNOSTKA.NIP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nip;

    /**
     * DPS_JEDNOSTKA.ORGAN_PROWADZACY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private OrganProwadzacy organProwadzacy;

    /**
     * DPS_JEDNOSTKA.REGON
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String regon;

    /**
     * DPS_JEDNOSTKA.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypJednostki typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DPS_JEDNOSTKA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DPS_JEDNOSTKA.ADRES_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * DPS_JEDNOSTKA.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return DPS_JEDNOSTKA.BRANCH
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Branch getBranch() {
        return branch;
    }

    /**
     * DPS_JEDNOSTKA.BRANCH
     *
     * @param branch
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setBranch(Branch branch) {
        this.branch = branch;
    }

    /**
     * @return DPS_JEDNOSTKA.KOD_KESO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodKeso() {
        return kodKeso;
    }

    /**
     * DPS_JEDNOSTKA.KOD_KESO
     *
     * @param kodKeso
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodKeso(String kodKeso) {
        this.kodKeso = kodKeso == null ? null : kodKeso.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.KOD_LOKALIZACJI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodLokalizacji() {
        return kodLokalizacji;
    }

    /**
     * DPS_JEDNOSTKA.KOD_LOKALIZACJI
     *
     * @param kodLokalizacji
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodLokalizacji(String kodLokalizacji) {
        this.kodLokalizacji = kodLokalizacji == null ? null : kodLokalizacji.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.KRS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKrs() {
        return krs;
    }

    /**
     * DPS_JEDNOSTKA.KRS
     *
     * @param krs
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKrs(String krs) {
        this.krs = krs == null ? null : krs.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * DPS_JEDNOSTKA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.NAZWA_SKROCONA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwaSkrocona() {
        return nazwaSkrocona;
    }

    /**
     * DPS_JEDNOSTKA.NAZWA_SKROCONA
     *
     * @param nazwaSkrocona
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwaSkrocona(String nazwaSkrocona) {
        this.nazwaSkrocona = nazwaSkrocona == null ? null : nazwaSkrocona.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.NIP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNip() {
        return nip;
    }

    /**
     * DPS_JEDNOSTKA.NIP
     *
     * @param nip
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNip(String nip) {
        this.nip = nip == null ? null : nip.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.ORGAN_PROWADZACY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public OrganProwadzacy getOrganProwadzacy() {
        return organProwadzacy;
    }

    /**
     * DPS_JEDNOSTKA.ORGAN_PROWADZACY
     *
     * @param organProwadzacy
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOrganProwadzacy(OrganProwadzacy organProwadzacy) {
        this.organProwadzacy = organProwadzacy;
    }

    /**
     * @return DPS_JEDNOSTKA.REGON
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getRegon() {
        return regon;
    }

    /**
     * DPS_JEDNOSTKA.REGON
     *
     * @param regon
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRegon(String regon) {
        this.regon = regon == null ? null : regon.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypJednostki getTyp() {
        return typ;
    }

    /**
     * DPS_JEDNOSTKA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypJednostki typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostka other = (DpsJednostka) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getBranch() == null ? other.getBranch() == null : this.getBranch().equals(other.getBranch()))
            && (this.getKodKeso() == null ? other.getKodKeso() == null : this.getKodKeso().equals(other.getKodKeso()))
            && (this.getKodLokalizacji() == null ? other.getKodLokalizacji() == null : this.getKodLokalizacji().equals(other.getKodLokalizacji()))
            && (this.getKrs() == null ? other.getKrs() == null : this.getKrs().equals(other.getKrs()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getNazwaSkrocona() == null ? other.getNazwaSkrocona() == null : this.getNazwaSkrocona().equals(other.getNazwaSkrocona()))
            && (this.getNip() == null ? other.getNip() == null : this.getNip().equals(other.getNip()))
            && (this.getOrganProwadzacy() == null ? other.getOrganProwadzacy() == null : this.getOrganProwadzacy().equals(other.getOrganProwadzacy()))
            && (this.getRegon() == null ? other.getRegon() == null : this.getRegon().equals(other.getRegon()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getBranch() == null) ? 0 : getBranch().hashCode());
        result = prime * result + ((getKodKeso() == null) ? 0 : getKodKeso().hashCode());
        result = prime * result + ((getKodLokalizacji() == null) ? 0 : getKodLokalizacji().hashCode());
        result = prime * result + ((getKrs() == null) ? 0 : getKrs().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getNazwaSkrocona() == null) ? 0 : getNazwaSkrocona().hashCode());
        result = prime * result + ((getNip() == null) ? 0 : getNip().hashCode());
        result = prime * result + ((getOrganProwadzacy() == null) ? 0 : getOrganProwadzacy().hashCode());
        result = prime * result + ((getRegon() == null) ? 0 : getRegon().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", branch=").append(branch);
        sb.append(", kodKeso=").append(kodKeso);
        sb.append(", kodLokalizacji=").append(kodLokalizacji);
        sb.append(", krs=").append(krs);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", nazwaSkrocona=").append(nazwaSkrocona);
        sb.append(", nip=").append(nip);
        sb.append(", organProwadzacy=").append(organProwadzacy);
        sb.append(", regon=").append(regon);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostka.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.Branch;
import pl.topteam.dps.enums.OrganProwadzacy;
import pl.topteam.dps.enums.TypJednostki;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DpsJednostka extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DPS_JEDNOSTKA.ADRES_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long adresId;

    /**
     * DPS_JEDNOSTKA.BRANCH
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Branch branch;

    /**
     * DPS_JEDNOSTKA.KOD_KESO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodKeso;

    /**
     * DPS_JEDNOSTKA.KOD_LOKALIZACJI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodLokalizacji;

    /**
     * DPS_JEDNOSTKA.KRS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String krs;

    /**
     * DPS_JEDNOSTKA.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * DPS_JEDNOSTKA.NAZWA_SKROCONA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwaSkrocona;

    /**
     * DPS_JEDNOSTKA.NIP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nip;

    /**
     * DPS_JEDNOSTKA.ORGAN_PROWADZACY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private OrganProwadzacy organProwadzacy;

    /**
     * DPS_JEDNOSTKA.REGON
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String regon;

    /**
     * DPS_JEDNOSTKA.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypJednostki typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DPS_JEDNOSTKA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DPS_JEDNOSTKA.ADRES_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * DPS_JEDNOSTKA.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return DPS_JEDNOSTKA.BRANCH
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Branch getBranch() {
        return branch;
    }

    /**
     * DPS_JEDNOSTKA.BRANCH
     *
     * @param branch
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setBranch(Branch branch) {
        this.branch = branch;
    }

    /**
     * @return DPS_JEDNOSTKA.KOD_KESO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodKeso() {
        return kodKeso;
    }

    /**
     * DPS_JEDNOSTKA.KOD_KESO
     *
     * @param kodKeso
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodKeso(String kodKeso) {
        this.kodKeso = kodKeso == null ? null : kodKeso.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.KOD_LOKALIZACJI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodLokalizacji() {
        return kodLokalizacji;
    }

    /**
     * DPS_JEDNOSTKA.KOD_LOKALIZACJI
     *
     * @param kodLokalizacji
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodLokalizacji(String kodLokalizacji) {
        this.kodLokalizacji = kodLokalizacji == null ? null : kodLokalizacji.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.KRS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKrs() {
        return krs;
    }

    /**
     * DPS_JEDNOSTKA.KRS
     *
     * @param krs
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKrs(String krs) {
        this.krs = krs == null ? null : krs.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * DPS_JEDNOSTKA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.NAZWA_SKROCONA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwaSkrocona() {
        return nazwaSkrocona;
    }

    /**
     * DPS_JEDNOSTKA.NAZWA_SKROCONA
     *
     * @param nazwaSkrocona
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwaSkrocona(String nazwaSkrocona) {
        this.nazwaSkrocona = nazwaSkrocona == null ? null : nazwaSkrocona.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.NIP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNip() {
        return nip;
    }

    /**
     * DPS_JEDNOSTKA.NIP
     *
     * @param nip
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNip(String nip) {
        this.nip = nip == null ? null : nip.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.ORGAN_PROWADZACY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public OrganProwadzacy getOrganProwadzacy() {
        return organProwadzacy;
    }

    /**
     * DPS_JEDNOSTKA.ORGAN_PROWADZACY
     *
     * @param organProwadzacy
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOrganProwadzacy(OrganProwadzacy organProwadzacy) {
        this.organProwadzacy = organProwadzacy;
    }

    /**
     * @return DPS_JEDNOSTKA.REGON
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getRegon() {
        return regon;
    }

    /**
     * DPS_JEDNOSTKA.REGON
     *
     * @param regon
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRegon(String regon) {
        this.regon = regon == null ? null : regon.trim();
    }

    /**
     * @return DPS_JEDNOSTKA.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypJednostki getTyp() {
        return typ;
    }

    /**
     * DPS_JEDNOSTKA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypJednostki typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostka other = (DpsJednostka) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getBranch() == null ? other.getBranch() == null : this.getBranch().equals(other.getBranch()))
            && (this.getKodKeso() == null ? other.getKodKeso() == null : this.getKodKeso().equals(other.getKodKeso()))
            && (this.getKodLokalizacji() == null ? other.getKodLokalizacji() == null : this.getKodLokalizacji().equals(other.getKodLokalizacji()))
            && (this.getKrs() == null ? other.getKrs() == null : this.getKrs().equals(other.getKrs()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getNazwaSkrocona() == null ? other.getNazwaSkrocona() == null : this.getNazwaSkrocona().equals(other.getNazwaSkrocona()))
            && (this.getNip() == null ? other.getNip() == null : this.getNip().equals(other.getNip()))
            && (this.getOrganProwadzacy() == null ? other.getOrganProwadzacy() == null : this.getOrganProwadzacy().equals(other.getOrganProwadzacy()))
            && (this.getRegon() == null ? other.getRegon() == null : this.getRegon().equals(other.getRegon()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getBranch() == null) ? 0 : getBranch().hashCode());
        result = prime * result + ((getKodKeso() == null) ? 0 : getKodKeso().hashCode());
        result = prime * result + ((getKodLokalizacji() == null) ? 0 : getKodLokalizacji().hashCode());
        result = prime * result + ((getKrs() == null) ? 0 : getKrs().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getNazwaSkrocona() == null) ? 0 : getNazwaSkrocona().hashCode());
        result = prime * result + ((getNip() == null) ? 0 : getNip().hashCode());
        result = prime * result + ((getOrganProwadzacy() == null) ? 0 : getOrganProwadzacy().hashCode());
        result = prime * result + ((getRegon() == null) ? 0 : getRegon().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", branch=").append(branch);
        sb.append(", kodKeso=").append(kodKeso);
        sb.append(", kodLokalizacji=").append(kodLokalizacji);
        sb.append(", krs=").append(krs);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", nazwaSkrocona=").append(nazwaSkrocona);
        sb.append(", nip=").append(nip);
        sb.append(", organProwadzacy=").append(organProwadzacy);
        sb.append(", regon=").append(regon);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
